/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@ricochet.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001-2004 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.core;

import java.io.InputStream;
import java.io.IOException;
import java.util.Date;
import java.util.List;
import java.util.Set;
import com.silverwrist.venice.except.AccessError;
import com.silverwrist.venice.except.DataException;
import com.silverwrist.venice.except.EmailException;
import com.silverwrist.venice.htmlcheck.HTMLChecker;

public interface ConferenceContext
{
  public static final int GET_ALL = 0;
  public static final int DISPLAY_NEW = 1;
  public static final int DISPLAY_ACTIVE = 2;
  public static final int DISPLAY_ALL = 3;
  public static final int DISPLAY_HIDDEN = 4;
  public static final int DISPLAY_ARCHIVED = 5;

  public static final int SORT_TOPICID = 0;
  public static final int SORT_NUMBER = 1;
  public static final int SORT_NAME = 2;
  public static final int SORT_UNREAD = 3;
  public static final int SORT_TOTAL = 4;
  public static final int SORT_DATE = 5;

  public static final int CUST_BLOCK_TOP = 0;
  public static final int CUST_BLOCK_BOTTOM = 1;

  public static final int IMPORT_MATCH_NUM = 0;
  public static final int IMPORT_MATCH_NAME = 1;

  public int getConfID();

  public String getName();
 
  public String getDescription();

  public Date getCreationDate();

  public Date getLastUpdateDate();

  public List getAliases() throws DataException;
  
  public List getHosts() throws DataException;
  
  public boolean canReadConference();

  public boolean canPostToConference();

  public boolean canCreateTopic();

  public boolean canChangeConference();

  public int getReadLevel() throws DataException, AccessError;

  public int getPostLevel() throws DataException, AccessError;

  public int getCreateLevel() throws DataException, AccessError;

  public int getHideLevel() throws DataException, AccessError;

  public int getNukeLevel() throws DataException, AccessError;

  public int getChangeLevel() throws DataException, AccessError;

  public int getDeleteLevel() throws DataException, AccessError;

  public void setSecurityLevels(int read, int post, int create, int hide, int nuke, int change, int delete)
      throws DataException, AccessError;

  public void setName(String val) throws DataException, AccessError;

  public void setDescription(String val) throws DataException, AccessError;

  public void addAlias(String alias) throws DataException, AccessError;

  public void removeAlias(String alias) throws DataException, AccessError;

  public void setMembership(int uid, int grant_level) throws DataException, AccessError;

  public void addMember(int uid, boolean as_host) throws DataException, AccessError;

  public void removeMember(int uid) throws DataException, AccessError;

  public int getCommunityGrantedLevel() throws DataException, AccessError;

  public void setCommunityGrantedLevel(int new_level) throws DataException, AccessError;

  public short getSequence() throws DataException, AccessError;

  public void setSequence(short seq) throws DataException, AccessError;

  public boolean getHideList() throws DataException, AccessError;

  public void setHideList(boolean flag) throws DataException, AccessError;

  public boolean canSetHideList();

  public String getDefaultPseud();

  public void setDefaultPseud(String val) throws DataException;

  public boolean anyUnread();

  public List getTopicList(int get_option, int sort_option, boolean ignore_sticky) throws DataException, AccessError;

  public List getTopicList(int get_option, int sort_option) throws DataException, AccessError;

  public TopicContext getTopic(short number) throws DataException, AccessError;

  public TopicContext addTopic(String title, String zp_pseud, String zp_text) throws DataException, AccessError;

  public TopicMessageContext getMessageByPostID(long postid) throws DataException, AccessError;

  public HTMLChecker getNewTopicPreviewChecker();

  public void fixSeen() throws DataException, AccessError;

  public List getActivePosters(int skip, int limit) throws DataException, AccessError;

  public List getActivePosters(int limit) throws DataException, AccessError;

  public List getActivePosters() throws DataException, AccessError;

  public List getActiveReaders(int skip, int limit) throws DataException, AccessError;

  public List getActiveReaders(int limit) throws DataException, AccessError;

  public List getActiveReaders() throws DataException, AccessError;

  public List getMemberList() throws DataException, AccessError;

  public int getMemberLevel(int uid) throws DataException, AccessError;

  public void delete() throws DataException, AccessError;

  public void deleteConference() throws DataException, AccessError;

  public boolean canDeleteConference();

  public boolean isInHotlist();

  public void addToHotlist() throws DataException;

  public boolean canAddToHotlist();

  public CommunityContext getEnclosingCommunity();

  public void removeFromHotlist() throws DataException;

  public void setHotlistSequence(int seq) throws DataException;

  public boolean displayPostPictures();

  public ConferenceProperties getProperties() throws DataException, AccessError;

  public void setProperties(ConferenceProperties props) throws DataException, AccessError;

  public SecurityInfo getSecurityInfo();

  public void sendInvitation(String address, String personal_message)
      throws AccessError, DataException, EmailException;

  public boolean canSendInvitation();

  public void sendMailToParticipants(boolean posters, int day_limit, String subject, String text)
      throws AccessError, DataException;

  public String getCustomBlock(int selector) throws DataException;

  public void setCustomBlock(int selector, String data) throws AccessError, DataException;

  public void removeCustomBlocks() throws AccessError, DataException;

  public List searchPosts(String search_terms, int offset, int count) throws AccessError, DataException;

  public int getSearchPostCount(String search_terms) throws AccessError, DataException;

  public String getPostLink() throws DataException;

  public String exportTopics(Set select_topics) throws AccessError, DataException, IOException;

  public List importMessages(InputStream xmlstream, int match_method, boolean create_new)
      throws AccessError, DataException;

} // end interface ConferenceContext
